Learn R Programming

sad (version 0.1.3)

getpareto: Find the pareto set

Description

Determine the set of pareto optimal forecasts in a matrix of scores

Usage

getpareto(scores)

Arguments

scores

a matrix of negatively oriented scores where the rows correspond to different forecasts and the columns denote different scores.

Value

a vector of indices indicating all members of the pareto set.

Details

The Pareto set contains all those forecasts for which no other forecast is better in every respect. In this function, we assume that all scores are negatively oriented, "better" therefore means lower values.